[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]
[bridgedb/master] Rename in EmailBasedDistributor.getBridges() `epoch` → `interval`.
commit 53732c492d29f094d17530bf60d740d957b21eab
Author: Isis Lovecruft <isis@xxxxxxxxxxxxxx>
Date: Thu Apr 9 05:03:37 2015 +0000
Rename in EmailBasedDistributor.getBridges() `epoch` â?? `interval`.
---
lib/bridgedb/Dist.py | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/lib/bridgedb/Dist.py b/lib/bridgedb/Dist.py
index 3f7835b..69d9eb6 100644
--- a/lib/bridgedb/Dist.py
+++ b/lib/bridgedb/Dist.py
@@ -448,7 +448,7 @@ class EmailBasedDistributor(Distributor):
"""Assign a bridge to this distributor."""
self.splitter.insert(bridge)
- def getBridges(self, bridgeRequest, epoch, N=1):
+ def getBridges(self, bridgeRequest, interval, N=1):
"""Return a list of bridges to give to a user.
:type bridgeRequest: :class:`~bridgedb.email.request.EmailBridgeRequest`
@@ -456,7 +456,7 @@ class EmailBasedDistributor(Distributor):
with the :data:`~bridgedb.bridgerequest.BridgeRequestBase.client`
attribute set to a string containing the client's full, canonicalized
email address.
:param epoch: The time period when we got this request. This can be
any string, so long as it changes with every period.
:param int N: The number of bridges to try to give back.
"""
@@ -501,7 +501,7 @@ class EmailBasedDistributor(Distributor):
elif wasWarned:
db.setWarnedEmail(bridgeRequest.client, False)
- pos = self.emailHmac("<%s>%s" % (epoch, bridgeRequest.client))
+ pos = self.emailHmac("<%s>%s" % (interval, bridgeRequest.client))
ring = None
ruleset = frozenset(bridgeRequest.filters)
_______________________________________________
@@ -456,7 +456,7 @@ class EmailBasedDistributor(Distributor):
attribute set to a string containing the client's full, canonicalized
email address.
- :param epoch: The time period when we got this request. This can be
+ :param interval: The time period when we got this request. This can be
any string, so long as it changes with every period.
:param int N: The number of bridges to try to give back.
tor-commits mailing list
tor-commits@xxxxxxxxxxxxxxxxxxxx
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits